==> zio-aws-codebuild_2.13-5.17.126.2-sources.jar: zio/aws/codebuild/model/DeleteBuildBatchResponse.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.codebuild.model.primitives.NonEmptyString
import scala.jdk.CollectionConverters._
final case class DeleteBuildBatchResponse(
    statusCode: Option[String] = None,
    buildsDeleted: Option[Iterable[NonEmptyString]] = None,
    buildsNotDeleted: Option[
      Iterable[zio.aws.codebuild.model.BuildNotDeleted]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.DeleteBuildBatchResponse = {
    import DeleteBuildBatchResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.DeleteBuildBatchResponse
      .builder()
      .optionallyWith(statusCode.map(value => value: java.lang.String))(
        _.statusCode
      )
      .optionallyWith(
        buildsDeleted.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.buildsDeleted)
      .optionallyWith(
        buildsNotDeleted.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.buildsNotDeleted)
      .build()
  }
  def asReadOnly: zio.aws.codebuild.model.DeleteBuildBatchResponse.ReadOnly =
    zio.aws.codebuild.model.DeleteBuildBatchResponse.wrap(buildAwsValue())
}
object DeleteBuildBatchResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.DeleteBuildBatchResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.DeleteBuildBatchResponse =
      zio.aws.codebuild.model.DeleteBuildBatchResponse(
        statusCode.map(value => value),
        buildsDeleted.map(value => value),
        buildsNotDeleted.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def statusCode: Option[String]
    def buildsDeleted: Option[List[NonEmptyString]]
    def buildsNotDeleted
        : Option[List[zio.aws.codebuild.model.BuildNotDeleted.ReadOnly]]
    def getStatusCode: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("statusCode", statusCode)
    def getBuildsDeleted: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("buildsDeleted", buildsDeleted)
    def getBuildsNotDeleted: ZIO[Any, AwsError, List[
      zio.aws.codebuild.model.BuildNotDeleted.ReadOnly
    ]] = AwsError.unwrapOptionField("buildsNotDeleted", buildsNotDeleted)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.DeleteBuildBatchResponse
  ) extends zio.aws.codebuild.model.DeleteBuildBatchResponse.ReadOnly {
    override val statusCode: Option[String] =
      scala.Option(impl.statusCode()).map(value => value: String)
    override val buildsDeleted: Option[List[NonEmptyString]] = scala
      .Option(impl.buildsDeleted())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codebuild.model.primitives.NonEmptyString(item)
        }.toList
      )
    override val buildsNotDeleted
        : Option[List[zio.aws.codebuild.model.BuildNotDeleted.ReadOnly]] = scala
      .Option(impl.buildsNotDeleted())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codebuild.model.BuildNotDeleted.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.DeleteBuildBatchResponse
  ): zio.aws.codebuild.model.DeleteBuildBatchResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-codebuild_2.13-6.20.83.2-sources.jar: zio/aws/codebuild/model/DeleteBuildBatchResponse.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codebuild.model.primitives.NonEmptyString
import scala.jdk.CollectionConverters._
final case class DeleteBuildBatchResponse(
    statusCode: Optional[String] = Optional.Absent,
    buildsDeleted: Optional[Iterable[NonEmptyString]] = Optional.Absent,
    buildsNotDeleted: Optional[
      Iterable[zio.aws.codebuild.model.BuildNotDeleted]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.DeleteBuildBatchResponse = {
    import DeleteBuildBatchResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.DeleteBuildBatchResponse
      .builder()
      .optionallyWith(statusCode.map(value => value: java.lang.String))(
        _.statusCode
      )
      .optionallyWith(
        buildsDeleted.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.buildsDeleted)
      .optionallyWith(
        buildsNotDeleted.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.buildsNotDeleted)
      .build()
  }
  def asReadOnly: zio.aws.codebuild.model.DeleteBuildBatchResponse.ReadOnly =
    zio.aws.codebuild.model.DeleteBuildBatchResponse.wrap(buildAwsValue())
}
object DeleteBuildBatchResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.DeleteBuildBatchResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.DeleteBuildBatchResponse =
      zio.aws.codebuild.model.DeleteBuildBatchResponse(
        statusCode.map(value => value),
        buildsDeleted.map(value => value),
        buildsNotDeleted.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def statusCode: Optional[String]
    def buildsDeleted: Optional[List[NonEmptyString]]
    def buildsNotDeleted
        : Optional[List[zio.aws.codebuild.model.BuildNotDeleted.ReadOnly]]
    def getStatusCode: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("statusCode", statusCode)
    def getBuildsDeleted: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("buildsDeleted", buildsDeleted)
    def getBuildsNotDeleted: ZIO[Any, AwsError, List[
      zio.aws.codebuild.model.BuildNotDeleted.ReadOnly
    ]] = AwsError.unwrapOptionField("buildsNotDeleted", buildsNotDeleted)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.DeleteBuildBatchResponse
  ) extends zio.aws.codebuild.model.DeleteBuildBatchResponse.ReadOnly {
    override val statusCode: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.statusCode())
      .map(value => value: String)
    override val buildsDeleted: Optional[List[NonEmptyString]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.buildsDeleted())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.codebuild.model.primitives.NonEmptyString(item)
          }.toList
        )
    override val buildsNotDeleted
        : Optional[List[zio.aws.codebuild.model.BuildNotDeleted.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.buildsNotDeleted())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.codebuild.model.BuildNotDeleted.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.DeleteBuildBatchResponse
  ): zio.aws.codebuild.model.DeleteBuildBatchResponse.ReadOnly = new Wrapper(
    impl
  )
}
